ChatActionHandler class

The handler for the chat actions.

Constructors

ChatActionHandler({Future<void> onSendMessage(ChatMessageSendOutput)?, Future<void> onMessageTap(ModelBaseMessage)?, Future<void> onImageThumbnailTap(AssetImageInfo)?, Future<void> onUserAvatarTap(ModelBaseUser?)?, Future<void> onMessageFailedStatusTap(ModelBaseMessage)?})
The constructor of ChatActionHandler.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onImageThumbnailTap → Future<void> Function(AssetImageInfo)?
The callback for tapping an image thumbnail.
final
onMessageFailedStatusTap → Future<void> Function(ModelBaseMessage)?
The callback for tapping a message failed status.
final
onMessageTap → Future<void> Function(ModelBaseMessage)?
The callback for tapping a message.
final
onSendMessage → Future<void> Function(ChatMessageSendOutput)?
The callback for sending a message.
final
onUserAvatarTap → Future<void> Function(ModelBaseUser?)?
The callback for tapping a user avatar.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited