ChatConfig class

The config for the chat.

Constructors

ChatConfig({int imageMaxCount = 9, String? inputBoxHintText, String? failedToSendText, String? photoPermissionDeniedText, String? photoPermissionDeniedButtonText, LoadingIndicatorType loadingIndicatorType = LoadingIndicatorType.sendBtnLoading, bool showUnreadCount = false, MessageAlignment messageAlignment = MessageAlignment.center})
The constructor of the chat config.

Properties

failedToSendText → String?
The text for the failed to send.
final
hashCode → int
The hash code for this object.
no setterinherited
imageMaxCount → int
The max count of the image.
final
inputBoxHintText → String?
The hint text for the input box.
final
loadingIndicatorType → LoadingIndicatorType
The type of the loading indicator.
final
messageAlignment → MessageAlignment
The alignment of the message.
final
photoPermissionDeniedButtonText → String?
The text for the photo permission denied button.
final
photoPermissionDeniedText → String?
The text for the photo permission denied.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showUnreadCount → bool
The flag for the show unread count.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited