ChatController class

The controller for the chat.

Constructors

ChatController({ChatActionHandler? actionHandler, ChatConfig? config})
The constructor of the chat controller.

Properties

actionHandler → ChatActionHandler?
The action handler for the chat.
final
chatScrollController → ChatScrollController
The scroll controller for the chat.
final
config ↔ ChatConfig
The config for the chat.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store ↔ ChatStore
The store for the chat.
latefinal
viewFactory → ViewFactory
The view factory for the chat.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollToBottom() → void
The method for the scroll to bottom.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited