ViewFactory class

The view factory for the chat.

Constructors

ViewFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFor(BuildContext context, {required ModelBaseMessage message, required bool isMessageFromCurrentUser}) → Widget?
The method for the build.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<T extends ModelBaseMessage>(MessageViewBuilder<T> builder) → void
The method for the register.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited