ModelBaseMessage class abstract

The base message for the chat.

Implementers

Constructors

ModelBaseMessage()

Properties

customContainerPadding → EdgeInsets?
custom padding for the message
no setter
displayDatetime → DateTime
The display datetime of the message.
no setter
forceNewBlock → bool
The force new block of the message.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the message.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int
The sequence of the message.
no setter
showAvatarAndPaddings → bool
to indicate whether to show avatar & paddings
no setter
status ↔ ModelBaseMessageStatus
The status of the message.
getter/setter pair
userId → String
The user id of the message.
no setter
widgetKey → GlobalKey<State<StatefulWidget>>
The widget key for the message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited