ModelBaseUser class abstract

The base user for the chat.

Implementers

Constructors

ModelBaseUser()

Properties

avatarUrl → String?
The avatar url of the user.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the user.
no setter
isCurrentUser → bool
The flag for the current user.
no setter
name → String
The name of the user.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited