ChatMessageSendOutput class

The output for the message send.

Constructors

ChatMessageSendOutput({required String message, required List<AssetImageInfo> imageFiles})
The constructor of the message send output.

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageFiles → List<AssetImageInfo>
The image files.
final
message → String
The message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited