ModelTextMessage class

The text message for the chat.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ModelTextMessage({required String id, required String userId, required int sequence, required DateTime displayDatetime, required String text, bool forceNewBlock = false})
The constructor of the text message.
ModelTextMessage.fromJson(Map<String, dynamic> json)
The factory method for the text message from the json.
factory

Properties

customContainerPadding → EdgeInsets?
custom padding for the message
no setterinherited
displayDatetime → DateTime
The display datetime of the message.
final
forceNewBlock → bool
The force new block of the message.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int
The sequence of the message.
final
showAvatarAndPaddings → bool
to indicate whether to show avatar & paddings
no setterinherited
status ↔ ModelBaseMessageStatus
The status of the message.
getter/setter pairinherited
text → String
The text of the message.
final
userId → String
The user id of the message.
final
widgetKey → GlobalKey<State<StatefulWidget>>
The widget key for the message.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
The method for the to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited