ModelUser class

The user for the chat.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ModelUser({required String id, required String name, required String avatarUrl, required bool isCurrentUser})
The constructor of the user.
ModelUser.fromJson(Map<String, dynamic> json)
The factory method for the user from the json.
factory

Properties

avatarUrl → String
The avatar url of the user.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the user.
final
isCurrentUser → bool
The flag for the current user.
final
name → String
The name of the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
The method for the to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited