ChatStore class

The store for the chat.

Inheritance

Constructors

ChatStore(ChatScrollController chatScrollController, ChatConfig config)

Properties

chatScrollController → ChatScrollController
The scroll controller for the chat.
finalinherited
config → ChatConfig
The config for the chat.
finalinherited
context → ReactiveContext
Override this method to use a custom context.
no setterinherited
currentUser → ModelBaseUser?
no setterinherited
focusNode → FocusNode
The focus node for the chat.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasUnreadMessages → bool
no setterinherited
imageFiles → ObservableList<AssetImageInfo>
no setterinherited
isInputBoxFocused → bool
no setterinherited
isSending → bool
no setterinherited
loadingIndicatorMessageId → String
The loading indicator message id.
finalinherited
reachImageSelectionLimit → bool
The flag for the reach image selection limit.
no setterinherited
readSequence → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequentialMessageMap → SequentialMessageMap
The sequential message map for the chat.
finalinherited
textEditingController → TextEditingController
The text editing controller for the chat.
finalinherited
unreadMessagesCount → int
no setterinherited
users → ObservableMap<String, ModelBaseUser>
no setterinherited

Methods

addMessage({required ModelBaseMessage message, bool isInitial = false}) → Future<void>
The action for the add message.
inherited
addMessages({required List<ModelBaseMessage> messages, bool isInitial = false}) → Future<void>
The action for the add messages.
inherited
addUser({required ModelBaseUser user}) → Future<void>
The action for the add user.
inherited
addUsers({required List<ModelBaseUser> users}) → Future<void>
The action for the add users.
inherited
clearAll() → Future<void>
The action for the clear all.
inherited
hideReplyGeneratingIndicator() → Future<void>
The action for the hide reply generating indicator.
inherited
isMessageFromCurrentUser(ModelBaseMessage message) → bool
The method for the is message from current user.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickImage(BuildContext context) → Future<void>
The action for the pick image.
inherited
postMessageProcessing({required bool isAtBottom, required bool isInitial, required List<ModelBaseMessage> newMessages}) → Future<void>
The action for the post message processing.
inherited
readAllMessages() → Future<void>
The action for the read all messages.
inherited
readMessage({required ModelBaseMessage message}) → Future<void>
The action for the read message.
inherited
removeImage({required AssetImageInfo image}) → Future<void>
The action for the remove image.
inherited
removeMessage({required ModelBaseMessage message}) → Future<void>
The action for the remove message.
inherited
removeMessageById({required String messageId}) → Future<void>
The action for the remove message by id.
inherited
removeMessages({required List<ModelBaseMessage> messages}) → Future<void>
The action for the remove messages.
inherited
sendMessage({required dynamic onSend(ChatMessageSendOutput)}) → Future<void>
The action for the send message.
inherited
showReplyGeneratingIndicator() → Future<void>
The action for the show reply generating indicator.
inherited
takePhoto(BuildContext context) → Future<void>
The action for the take photo.
inherited
toString() → String
A string representation of this object.
inherited
updateSendStatus({required String messageId, required ModelBaseMessageStatus status}) → Future<void>
The action for the update send status.
inherited
updateUnreadStatus() → Future<void>
The action for the update unread status.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited