ChatStoreBase class abstract

The base class for the chat store.

Implementers

Constructors

ChatStoreBase(ChatScrollController chatScrollController, ChatConfig config)
The constructor of the chat store.

Properties

chatScrollController → ChatScrollController
The scroll controller for the chat.
final
config → ChatConfig
The config for the chat.
final
context → ReactiveContext
Override this method to use a custom context.
no setterinherited
focusNode → FocusNode
The focus node for the chat.
final
hashCode → int
The hash code for this object.
no setterinherited
loadingIndicatorMessageId → String
The loading indicator message id.
final
reachImageSelectionLimit → bool
The flag for the reach image selection limit.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequentialMessageMap → SequentialMessageMap
The sequential message map for the chat.
final
textEditingController → TextEditingController
The text editing controller for the chat.
final

Methods

addMessage({required ModelBaseMessage message, bool isInitial = false}) → Future<void>
The action for the add message.
addMessages({required List<ModelBaseMessage> messages, bool isInitial = false}) → Future<void>
The action for the add messages.
addUser({required ModelBaseUser user}) → Future<void>
The action for the add user.
addUsers({required List<ModelBaseUser> users}) → Future<void>
The action for the add users.
clearAll() → Future<void>
The action for the clear all.
hideReplyGeneratingIndicator() → Future<void>
The action for the hide reply generating indicator.
isMessageFromCurrentUser(ModelBaseMessage message) → bool
The method for the is message from current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickImage(BuildContext context) → Future<void>
The action for the pick image.
postMessageProcessing({required bool isAtBottom, required bool isInitial, required List<ModelBaseMessage> newMessages}) → Future<void>
The action for the post message processing.
readAllMessages() → Future<void>
The action for the read all messages.
readMessage({required ModelBaseMessage message}) → Future<void>
The action for the read message.
removeImage({required AssetImageInfo image}) → Future<void>
The action for the remove image.
removeMessage({required ModelBaseMessage message}) → Future<void>
The action for the remove message.
removeMessageById({required String messageId}) → Future<void>
The action for the remove message by id.
removeMessages({required List<ModelBaseMessage> messages}) → Future<void>
The action for the remove messages.
sendMessage({required dynamic onSend(ChatMessageSendOutput)}) → Future<void>
The action for the send message.
showReplyGeneratingIndicator() → Future<void>
The action for the show reply generating indicator.
takePhoto(BuildContext context) → Future<void>
The action for the take photo.
toString() → String
A string representation of this object.
inherited
updateSendStatus({required String messageId, required ModelBaseMessageStatus status}) → Future<void>
The action for the update send status.
updateUnreadStatus() → Future<void>
The action for the update unread status.

Operators

operator ==(Object other) → bool
The equality operator.
inherited