SequentialMessageMap class

The sequential message map.

Inheritance

Constructors

SequentialMessageMap()

Properties

context → ReactiveContext
Override this method to use a custom context.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageStatusMap → ObservableMap<String, ModelBaseMessageStatus>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequentialValues → ObservableList<ModelBaseMessage>
The computed for the sequential values.
no setterinherited
sequentialValuesReversed → ObservableList<ModelBaseMessage>
The computed for the sequential values reversed.
no setterinherited

Methods

clearAll() → void
The action for the clear all.
inherited
getById(String id) → ModelBaseMessage?
The action for the get by id.
inherited
getHighestSequence() → int
The action for the get highest sequence.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String id) → void
The action for the remove.
inherited
toString() → String
A string representation of this object.
inherited
upsert(ModelBaseMessage msg) → void
The action for the upsert.
inherited
upsertAll(List<ModelBaseMessage> msgs) → void
The action for the upsert all.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited