ChatColorThemeData class

The color theme data for the chat.

Constructors

ChatColorThemeData({Color backgroundColor = const Color(0xFFF5F5F5), Color inputBoxColor = Colors.white, Color myMessageColor = const Color(0xFFE5E5EA), Color otherMessageColor = Colors.white, Color primary = const Color(0xFFF86526), Color unreadIndicatorBackgroundColor = Colors.white, Color sendingIndicatorColor = const Color(0xFFF86526)})
The constructor for the chat color theme data.

Properties

backgroundColor → Color
The background color.
final
hashCode → int
The hash code for this object.
no setterinherited
inputBoxColor → Color
The input box color.
final
myMessageColor → Color
The my message color.
final
otherMessageColor → Color
The other message color.
final
primary → Color
The primary color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendingIndicatorColor → Color
The sending indicator color.
final
unreadIndicatorBackgroundColor → Color
The unread indicator background color.
final

Methods

copyWith({Color? backgroundColor}) → ChatColorThemeData
The method for the copy with.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dark → ChatColorThemeData
The dark color theme data.
no setter
light → ChatColorThemeData
The light color theme data.
no setter