ChatLayoutThemeData class

The layout theme data for the chat.

Constructors

ChatLayoutThemeData({EdgeInsets chatViewPadding = const EdgeInsets.all(16), double userAvatarSize = 36, double avatarAndMessageSpacing = 8, TextStyle failedToSendTextStyle = const TextStyle(fontSize: 11, color: Color(0xFFFF3B30), fontWeight: FontWeight.w400, height: 1.545)})
The constructor for the chat layout theme data.
const

Properties

avatarAndMessageSpacing → double
The avatar and message spacing.
final
chatViewPadding → EdgeInsets
The chat view padding.
final
failedToSendTextStyle → TextStyle
The failed to send text style.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAvatarSize → double
The user avatar size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited