ChatThemeData class

The data for the chat theme.

Constructors

ChatThemeData({required ChatColorThemeData light, required ChatColorThemeData dark, ChatLayoutThemeData layout = const ChatLayoutThemeData()})
The constructor for the chat theme data.

Properties

dark ↔ ChatColorThemeData
The dark color theme data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
layout ↔ ChatLayoutThemeData
The layout theme data.
getter/setter pair
light ↔ ChatColorThemeData
The light color theme data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited