InputBox class

The input box for the chat.

Inheritance

Constructors

InputBox({Key? key, required ChatController controller, required TextEditingController textEditingController, required FocusNode focusNode, required dynamic onSend(), required dynamic onCameraTap(), required dynamic onAlbumTap(), required dynamic onImageTap(AssetImageInfo), required dynamic onImageRemove(AssetImageInfo)})
The constructor for the input box.

Properties

controller → ChatController
The controller for the chat.
final
focusNode → FocusNode
The focus node.
final
hashCode → int
The hash code for this object.
no setterinherited
inputBoxHorizontalMargin → double
The input box horizontal margin.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAlbumTap → dynamic Function()
The on album tap callback.
final
onCameraTap → dynamic Function()
The on camera tap callback.
final
onImageRemove → dynamic Function(AssetImageInfo)
The on image remove callback.
final
onImageTap → dynamic Function(AssetImageInfo)
The on image tap callback.
final
onSend → dynamic Function()
The on send callback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store ↔ ChatStore
The store for the chat.
latefinal
textEditingController → TextEditingController
The text editing controller.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited