InputBoxTextField class

The input box text field.

Inheritance

Constructors

InputBoxTextField({Key? key, double inputBoxHorizontalMargin = 16.0, required ChatController controller, required TextEditingController textEditingController, required FocusNode focusNode, required dynamic onSend(), required dynamic onCameraTap(), required dynamic onAlbumTap()})
The constructor for the input box text field.
const

Properties

controller → ChatController
The controller for the chat.
final
focusNode → FocusNode
The focus node.
final
hashCode → int
The hash code for this object.
no setterinherited
inputBoxHorizontalMargin → double
The input box horizontal margin.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAlbumTap → dynamic Function()
The on album tap callback.
final
onCameraTap → dynamic Function()
The on camera tap callback.
final
onSend → dynamic Function()
The on send callback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textEditingController → TextEditingController
The text editing controller.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<InputBoxTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited